CursorPage<T> typedef
The result of one CursorSyncCapable.readChanges page: the changed entities plus the opaque cursor to pass on the next call.
Implementation
typedef CursorPage<T> = ({List<T> items, String nextCursor});
The result of one CursorSyncCapable.readChanges page: the changed entities plus the opaque cursor to pass on the next call.
typedef CursorPage<T> = ({List<T> items, String nextCursor});