readSince abstract method
Returns entities modified at or after since, honoring userId and
scope the same way readAll does.
Implementation
Future<List<T>> readSince(DateTime since, {String? userId, DatumSyncScope? scope});
Returns entities modified at or after since, honoring userId and
scope the same way readAll does.
Future<List<T>> readSince(DateTime since, {String? userId, DatumSyncScope? scope});