changeStream method
Stream of changes that occur in the local storage. Return null if the adapter doesn't support change notifications.
Implementation
@override
Stream<DatumChangeDetail<T>>? changeStream() => _changeController.stream;
Stream of changes that occur in the local storage. Return null if the adapter doesn't support change notifications.
@override
Stream<DatumChangeDetail<T>>? changeStream() => _changeController.stream;