getAllRawData method

  1. @override
Future<List<Map<String, dynamic>>> getAllRawData({
  1. String? userId,
})
override

Fetch all data for a user as a list of raw maps. This is used during schema migrations to avoid deserialization issues.

Implementation

@override
Future<List<Map<String, dynamic>>> getAllRawData({String? userId}) async {
  final items = await readAll(userId: userId);
  return items.map((e) => e.toDatumMap()).toList();
}