getLastSyncResult method
Retrieves the result of the last synchronization for a user.
Implementation
@override
Future<DatumSyncResult<T>?> getLastSyncResult(String userId) async => _lastSyncResults[userId];
Retrieves the result of the last synchronization for a user.
@override
Future<DatumSyncResult<T>?> getLastSyncResult(String userId) async => _lastSyncResults[userId];