watchAll method

  1. @override
Stream<List<T>>? watchAll({
  1. String? userId,
  2. bool includeInitialData = true,
})
override

Watch all items, emitting a new list on any change.

The includeInitialData parameter controls whether the stream should immediately emit the current list of all items. Defaults to true. If false, the stream will only emit when a change occurs. Return null if the adapter doesn't support reactive queries.

Implementation

@override
Stream<List<T>>? watchAll({String? userId, bool includeInitialData = true}) => _watch(() => readAll(userId: userId), userId: userId, includeInitialData: includeInitialData);