ConflictResolvedEvent<T extends DatumEntityInterface> class

Event emitted after a conflict has been successfully resolved.

Inheritance

Constructors

ConflictResolvedEvent({required String userId, required String entityId, required DatumConflictResolution<T> resolution, DateTime? timestamp})
Creates a conflict resolved event.

Properties

entityId → String
The ID of the entity that was involved in the conflict.
final
hashCode → int
The hash code for this object.
no setterinherited
resolution → DatumConflictResolution<T>
The resolution that was applied.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
The time at which the event occurred.
finalinherited
userId → String
The user ID associated with this event.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited