DatumSyncEvent<T extends DatumEntityInterface> class abstract

Base class for all synchronization-related events.

Implementers
Annotations
  • @immutable

Constructors

DatumSyncEvent({required String userId, DateTime? timestamp})
Creates a base sync event.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
The time at which the event occurred.
final
userId → String
The user ID associated with this event.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited