DatumMiddleware<T extends DatumEntityInterface> class abstract

Middleware for intercepting and transforming data during CRUD operations.

Middleware components are executed in the order they are registered.

Constructors

DatumMiddleware()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
transformAfterFetch(T item) → FutureOr<T>
Transforms an entity after it has been fetched from a data source.
transformBeforeSave(T item) → FutureOr<T>
Transforms an entity before it is saved via a create or update operation.

Operators

operator ==(Object other) → bool
The equality operator.
inherited