SchemaColumnRemoved class final
A stored column not present in the declaration will be dropped
(only when autoMigrateDropColumns is on).
- Inheritance
-
- Object
- SchemaChange
- SchemaColumnRemoved
Constructors
- SchemaColumnRemoved(String name)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited