AddColumn class

Inheritance

Constructors

AddColumn(String name, {Object? defaultValue, Object? compute(Map<String, dynamic> row)?, bool overwrite = false, String? sqlType, String? sqlExpression})

Properties

compute Object? Function(Map<String, dynamic> row)?
final
defaultValue Object?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
overwrite bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sqlExpression String?
SQL expression backfilling the new column; the SQL counterpart of compute. Ignored by the map-based path.
final
sqlType String?
SQL column type for DDL generation; inferred from defaultValue when omitted. Ignored by the map-based path.
final

Methods

apply(Map<String, dynamic> row) Map<String, dynamic>
Applies this operation to row and returns the resulting row.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited