apply abstract method

Map<String, dynamic> apply(
  1. Map<String, dynamic> row
)

Applies this operation to row and returns the resulting row.

row is a private copy owned by the migration pipeline; implementations may mutate and return it, or return a new map.

Implementation

Map<String, dynamic> apply(Map<String, dynamic> row);