RemoveColumn class

Inheritance

Constructors

RemoveColumn(String name)

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(Map<String, dynamic> row) Map<String, dynamic>
Applies this operation to row and returns the resulting row.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited