where property
When set, only rows for which this predicate returns true are migrated. Combined with entityType when both are given.
Implementation
final bool Function(Map<String, dynamic> row)? where;
When set, only rows for which this predicate returns true are migrated. Combined with entityType when both are given.
final bool Function(Map<String, dynamic> row)? where;