TransformColumn class

Inheritance

Constructors

TransformColumn(String name, Object? transform(Object? value, Map<String, dynamic> row), {bool applyIfAbsent = false, String? sqlExpression})

Properties

applyIfAbsent bool
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sqlExpression String?
SQL expression equivalent of transform (UPDATE t SET name = <expr>). Required for the SQL migration path; ignored by the map-based path.
final
transform Object? Function(Object? value, Map<String, dynamic> row)
final

Methods

apply(Map<String, dynamic> row) Map<String, dynamic>
Applies this operation to row and returns the resulting row.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited