apply method
Applies this operation to row and returns the resulting row.
row is a private copy owned by the migration pipeline; implementations
may mutate and return it, or return a new map.
Implementation
@override
Map<String, dynamic> apply(Map<String, dynamic> row) {
if (!applyIfAbsent && !row.containsKey(name)) return row;
row[name] = transform(row[name], row);
return row;
}