toSqlStatements abstract method
The SQL statements equivalent to this operation, run in order.
Implementation
List<String> toSqlStatements(String table, SqlDialect dialect);
The SQL statements equivalent to this operation, run in order.
List<String> toSqlStatements(String table, SqlDialect dialect);