CRDT<T> class abstract interface

Base interface for Conflict-free Replicated Data Types (CRDTs).

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → T
Returns the current value of the CRDT.
no setter

Methods

merge(covariant CRDT<T> other) → CRDT<T>
Merges this CRDT with another of the same type.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the CRDT state to a map for serialization.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited