ORSet<T> class
An Observed-Remove Set CRDT.
Elements can be added and removed across multiple replicas. It uses a "win" strategy for concurrent add/remove of the same element.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited -
value
→ Set<
T> -
Returns the current value of the CRDT.
no setteroverride
Methods
-
add(
T element, String tag) → ORSet< T> -
merge(
covariant ORSet< T> other) → ORSet<T> -
Merges this CRDT with another of the same type.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
T element) → ORSet< T> -
toMap(
{Object? encoder(T element)?}) → Map< String, dynamic> -
Serializes in the format-2 entry shape.
encoderconverts an element to a JSON-encodable value; by default the element itself is stored (correct for JSON primitives — matching what fromMap's decoder expects back).override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited