incrementClock abstract method
Returns a new instance with the vector clock incremented for replicaId.
Implementation
@override
DatumEntityInterface incrementClock(String replicaId);
Returns a new instance with the vector clock incremented for replicaId.
@override
DatumEntityInterface incrementClock(String replicaId);