capture<R> method

R capture<R>(
  1. R cb<E extends DatumEntityInterface>()
)

A helper method to capture the generic type T at runtime. This is used to get a reliable Type object as a key for maps.

Implementation

R capture<R>(R Function<E extends DatumEntityInterface>() cb) {
  return cb<T>();
}