descriptor static method
The descriptor for relation name on type, or null.
Implementation
static RelationDescriptor? descriptor(Type type, String name) => _schemas[type]?[name];
The descriptor for relation name on type, or null.
static RelationDescriptor? descriptor(Type type, String name) => _schemas[type]?[name];