of static method
The relation schema registered for type, or null if none.
Implementation
static Map<String, RelationDescriptor>? of(Type type) => _schemas[type];
The relation schema registered for type, or null if none.
static Map<String, RelationDescriptor>? of(Type type) => _schemas[type];