RelationSchemaProvider class abstract interface

Contract for objects that can describe their relation schema without needing their relation values to be loaded. Implemented by RelationalDatumEntity.

Properties

hashCode int
The hash code for this object.
no setterinherited
relationSchema Map<String, RelationDescriptor>
The relation schema for this entity, keyed by relation name.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited