DatumCoreRole enum
Which of the six standard sync fields a spec represents, when built by datumCoreFieldSpecs. Payload fields have no role.
Values
- id → const DatumCoreRole
- userId → const DatumCoreRole
- modifiedAt → const DatumCoreRole
- createdAt → const DatumCoreRole
- version → const DatumCoreRole
- isDeleted → const DatumCoreRole
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DatumCoreRole> - A constant List of the values in this enum, in order of their declaration.