renamedFrom property
The previous serialized name of this field. Auto-migration treats a store that has renamedFrom but not name as a rename instead of a drop + add (which would lose data).
Implementation
final String? renamedFrom;
The previous serialized name of this field. Auto-migration treats a store that has renamedFrom but not name as a rename instead of a drop + add (which would lose data).
final String? renamedFrom;