CollectingLogSink class

A DatumLogSink that collects entries in memory. Useful for tests.

Implemented types

Constructors

CollectingLogSink()

Properties

entries List<LogEntry>
The entries written so far, in order.
final
hashCode int
The hash code for this object.
no setterinherited
messages List<String>
The formatted strings written so far, in order.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
Clears all collected output.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
write(LogEntry entry, String formatted) → void
Writes a single, already-formatted log entry.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited