ConsoleLogSink class
The default DatumLogSink, printing to stdout via print.
- Implemented types
Constructors
- ConsoleLogSink()
-
Creates a console sink.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
LogEntry entry, String formatted) → void -
Writes a single, already-formatted log
entry.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited