watchCount method
Watch the total count of entities, optionally matching a query. Return null if the adapter does not support this feature.
Implementation
@override
Stream<int>? watchCount({DatumQuery? query, String? userId}) {
return _watch(() async => query != null ? (await this.query(query, userId: userId)).length : (await readAll(userId: userId)).length, userId: userId);
}