apply method
Applies this operation to row and returns the resulting row.
row is a private copy owned by the migration pipeline; implementations
may mutate and return it, or return a new map.
Implementation
@override
Map<String, dynamic> apply(Map<String, dynamic> row) {
if (!row.containsKey(from)) return row;
if (row.containsKey(to)) {
row.remove(from);
return row;
}
row[to] = row.remove(from);
return row;
}