RowTransform class
See ColumnOperation.row.
- Inheritance
-
- Object
- ColumnOperation
- RowTransform
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sql
→ List<
String> ? -
SQL statements equivalent to transform, run verbatim in order.
Required for the SQL migration path; ignored by the map-based path.
final
-
transform
→ Map<
String, dynamic> Function(Map<String, dynamic> row) -
final
Methods
-
apply(
Map< String, dynamic> row) → Map<String, dynamic> -
Applies this operation to
rowand returns the resulting row.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited