DatumConflictResolution<T extends DatumEntityInterface>.deleteLocal constructor
const
DatumConflictResolution<T extends DatumEntityInterface>.deleteLocal ([
- String? message
Creates a resolution that accepts a remote deletion, removing the local copy of the entity.
Intended for a DatumConflictType.deletionConflict where the remote no longer has the entity (remote is null). It uses DatumResolutionStrategy.takeRemote with no resolved data, which the sync engine applies as a local delete.
Implementation
const DatumConflictResolution.deleteLocal([String? message]) : this._(strategy: DatumResolutionStrategy.takeRemote, message: message);